<?php

	/**
	 * Ceska lokalizace phpPgAdmin-u.
	 * Zalozeno na slovenske lokalizaci. Thx.
	 *                                      libor(at)conet.cz
	 */

	// Language and character set
	$lang['applang'] = 'Česky';
	$lang['appcharset'] = 'utf8';
	$lang['applocale'] = 'cs_CZ';
	$lang['appdbencoding'] = 'UNICODE';
	$lang['applangdir'] = 'ltr';

	// Basic strings
	$lang['strintro'] = 'Vítejte v phpPgAdminu.';
	$lang['strlogin'] = 'Přihlášení';
	$lang['strppahome'] = 'Domovská stránka phpPgAdmin';
	$lang['strpgsqlhome'] = 'Domovská stránka PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'Lokální dokumentace k PostgreSQL';
	$lang['strreportbug'] = 'Nahlásit chybu';
	$lang['strviewfaq'] = 'Prohlédnout FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	$lang['strloginfailed'] = 'Přihlášení selhalo';
	$lang['strserver'] = 'Server';
	$lang['strlogout'] = 'Odhlásit';
	$lang['strowner'] = 'Vlastník';
	$lang['strlogindisallowed'] = 'Přihlášení zakázáno';
	$lang['straction'] = 'Akce';
	$lang['stractions'] = 'Akce';
	$lang['strname'] = 'Jméno';
	$lang['strdefinition'] = 'Definice';
	$lang['stroperators'] = 'Operátory';
	$lang['straggregates'] = 'Agregáty';
	$lang['strproperties'] = 'Vlastnosti';
	$lang['strbrowse'] = 'Přehled';
	$lang['strdrop'] = 'Smazat';
	$lang['strdropped'] = 'Smazaný';
	$lang['strnull'] = 'Nulový';
	$lang['strnotnull'] = 'Nenulový';
	$lang['strprev'] = 'Předchozí';
	$lang['strnext'] = 'Další';
	$lang['strfailed'] = 'Selhalo';
	$lang['strcreate'] = 'Vytvořit';
	$lang['strfirst'] = '<< První';
	$lang['strlast'] = 'Poslední >>';
	$lang['strcreated'] = 'Vytvořené';
	$lang['strcomment'] = 'Komentář';
	$lang['strlength'] = 'Délka';
	$lang['strdefault'] = 'Předvolené';
	$lang['stralter'] = 'Změnit';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'Storno';
	$lang['strsave'] = 'Uložit';
	$lang['strreset'] = 'Reset';
	$lang['strinsert'] = 'Vložit';
	$lang['strselect'] = 'Vybrat';
	$lang['strdelete'] = 'Smazat';
	$lang['strupdate'] = 'Aktualizovat';
	$lang['strreferences'] = 'Reference';
	$lang['stryes'] = 'Yo';
	$lang['strno'] = 'Ne';
	$lang['stredit'] = 'Upravit';
	$lang['strcolumns'] = 'Sloupce';
	$lang['strtrue'] = 'PRAVDA';
	$lang['strfalse'] = 'NEPRAVDA';
	$lang['strrows'] = 'Řádky';
	$lang['strexample'] = 'např.';
	$lang['strback'] = 'Zpět';
	$lang['strrowsaff'] = 'řádků změněno.';
	$lang['strobjects'] = 'objektů';
	$lang['strqueryresults'] = 'Výsledky dotazu';
	$lang['strshow'] = 'Ukázat';
	$lang['strempty'] = 'Vyprázdnit';
	$lang['strlanguage'] = 'Jazyk';
	$lang['strencoding'] = 'Kódovaní';
	$lang['strvalue'] = 'Hodnota';
	$lang['strunique'] = 'Unikátní';
	$lang['strprimary'] = 'Primární';
	$lang['strexport'] = 'Exportovat';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = 'Vykonej';
	$lang['strimport'] = 'Import';
	$lang['stradmin'] = 'Admin';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analyzovat';
	$lang['strclusterindex'] = 'Cluster';
	$lang['strreindex'] = 'Reindex';
	$lang['strrun'] = 'Spustit';
	$lang['strclustered'] = 'Clustered?';
	$lang['stradd'] = 'Přidat';
	$lang['strevent'] = 'Událost';
	$lang['strwhere'] = 'Kde';
	$lang['strinstead'] = 'Udělat namísto';
	$lang['strwhen'] = 'Když';
	$lang['strformat'] = 'Formát';

	// Error handling
	$lang['strdata'] = 'Data';
	$lang['strconfirm'] = 'Potvrzení';
	$lang['strexpression'] = 'Výraz';
	$lang['strellipsis'] = '...';
	$lang['strexpand'] = 'Rozbal';
	$lang['strcollapse'] = 'Sbal';
	$lang['strexplain'] = 'Vysvětli';
	$lang['strexplainanalyze'] = 'Vysvětli analýzu';
	$lang['strfind'] = 'Hledej';
	$lang['stroptions'] = 'Nastavení';
	$lang['strrefresh'] = 'Obnov';
	$lang['strdownload'] = 'Stáhnout';
	$lang['strdownloadgzipped'] = 'Komprimovat gzipem a stáhnout';
	$lang['strinfo'] = 'Info';
	$lang['stroids'] = 'OIDy';
	$lang['stradvanced'] = 'Pokročilé';
	$lang['strvariables'] = 'Proměnné';
	$lang['strprocess'] = 'Proces';
	$lang['strprocesses'] = 'Processy';
	$lang['strsetting'] = 'Nastavení';
	$lang['strparameters'] = 'Parametry';
	$lang['streditsql'] = 'Uprav SQL';
	$lang['strpaginate'] = 'Stránkování výsledků';
	$lang['strstarttime'] = 'Počáteční čas';
	$lang['strbadconfig'] = 'Your config.inc.php is out of date. You will need to regenerate it from the new config.inc.php-dist.';
	$lang['strnotloaded'] = 'PHP není zakompilováno s podporou PostgreSQL';
	$lang['strbadschema'] = 'Nastaveno špatné schéma.';
	$lang['strbadencoding'] = 'Nastavení kódovaní v databáze selhalo.';
	$lang['strsqlerror'] = 'SQL chyba:';
	$lang['strinstatement'] = 'Ve výrazu:';
	$lang['strinvalidparam'] = 'Chybné parametry skriptu.';
	$lang['strnodata'] = 'Nenalezeny žádné záznamy.';

	// Tables
	$lang['strnoobjects'] = 'Žádné objekty nenalezeny.';
	$lang['strrownotunique'] = 'Žádný jednoznačný identifikátor pro tento řádek.';
	$lang['strnoreportsdb'] = 'Nevytvořil jsi databází pro reporty. Příslušné pokyny najdeš v souboru INSTALL.';
	$lang['strtable'] = 'Tabulka';
	$lang['strtables'] = 'Tabulky';
	$lang['strshowalltables'] = 'Zobrazit všechny tabulky';
	$lang['strnotables'] = 'Nenalezeny žádné tabulky.';
	$lang['strnotable'] = 'Nenalezena žádná tabulka.';
	$lang['strcreatetable'] = 'Vytvořit tabulku';
	$lang['strtablename'] = 'Název tabulky';
	$lang['strtableneedsname'] = 'Musíš zadat názov tabulky.';
	$lang['strtableneedsfield'] = 'Musíš zadat aspoň jedno pole.';
	$lang['strtableneedscols'] = 'Tables require a valid number of columns.';
	$lang['strtablecreated'] = 'Tabulka vytvořená.';
	$lang['strtablecreatedbad'] = 'Tabulka nebola vytvořená.';
	$lang['strconfdroptable'] = 'Opravdu chceš odstranit tabulku "%s"?';
	$lang['strtabledropped'] = 'Tabulka odstraněná.';
	$lang['strtabledroppedbad'] = 'Tabulka nebyla odstraněná.';
	$lang['strconfemptytable'] = 'Opravdu chceš vyprázdnit tabulku "%s"?';
	$lang['strtableemptied'] = 'Tabulka vyprázdněna.';
	$lang['strtableemptiedbad'] = 'Tabulka nebyla vyprázdněna.';
	$lang['strinsertrow'] = 'Vložit řádek';
	$lang['strrowinserted'] = 'Řádek vložen.';
	$lang['strrowinsertedbad'] = 'Řádek nebyl vložen.';
	$lang['streditrow'] = 'Upravit řádek';
	$lang['strrowupdated'] = 'Řádek upraven.';
	$lang['strrowupdatedbad'] = 'Řádek nebyl upraven.';
	$lang['strdeleterow'] = 'Smazat řádek';
	$lang['strconfdeleterow'] = 'Opravdu chceš smazat tento řádek?';
	$lang['strrowdeleted'] = 'Řádek smazán.';
	$lang['strrowdeletedbad'] = 'Řádek nebyl smazán.';
	$lang['strsaveandrepeat'] = 'Uložit & opakovat';
	$lang['strfield'] = 'Pole';
	$lang['strfields'] = 'Pole';
	$lang['strnumfields'] = 'Počet polí';
	$lang['strfieldneedsname'] = 'Musíš pomenovat pole';
	$lang['strselectneedscol'] = 'Musíš vybrat aspoň jeden stoupec';
	$lang['straltercolumn'] = 'Změnit sloupec';
	$lang['strselectallfields'] = 'Označ všechny pole';
	$lang['strcolumnaltered'] = 'Sloupec změněný.';
	$lang['strselectunary'] = 'Unární operátory nemohou mít hodnoty.';
	$lang['strcolumnalteredbad'] = 'Sloupec nebyl změněný.';
	$lang['strconfdropcolumn'] = 'Opravdu chceš smazat sloupec "%s" z tabulky "%s"?';
	$lang['strcolumndropped'] = 'Sloupec smazán.';
	$lang['strcolumndroppedbad'] = 'Sloupec nebyl smazán.';
	$lang['straddcolumn'] = 'Přidat sloupec';
	$lang['strcolumnadded'] = 'Sloupec přidaný.';
	$lang['strcolumnaddedbad'] = 'Sloupec nebyl přidaný.';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = 'Tabulka změněna.';
	$lang['strtablealteredbad'] = 'Změna tabulky se nepodařila.';

	$lang['strstructureonly'] = 'Pouze struktura';
	$lang['strstructureanddata'] = 'Struktura a data';
	// Users
	$lang['struser'] = 'Uživatel';
	$lang['strusername'] = 'Jméno uživatele';
	$lang['strpassword'] = 'Heslo';
	$lang['strsuper'] = 'Superuser?';
	$lang['strcreatedb'] = 'Vytvářet DB?';
	$lang['strexpires'] = 'Expiruje';
	$lang['strsessiondefaults'] = 'Standardní hodnoty session';
	$lang['strnousers'] = 'Nenalezen žádný uživatel.';
	$lang['struserupdated'] = 'Uživatel upraven.';
	$lang['struserupdatedbad'] = 'Uživatel nebyl upraven.';
	$lang['strshowallusers'] = 'Zobrazit všechny uživatele';
	$lang['strcreateuser'] = 'Vytvořit uživatele';
	$lang['struserneedsname'] = 'Musíte zadat jméno uživatele.';
	$lang['strusercreated'] = 'Užívatel vytvořený.';
	$lang['strusercreatedbad'] = 'Užívatel nebyl vytvořený.';
	$lang['strconfdropuser'] = 'Opravdu chceš smazat uživatele "%s"?';
	$lang['struserdropped'] = 'Uživatel smazán.';
	$lang['struserdroppedbad'] = 'Uživatel nebyl smazán.';
	$lang['straccount'] = 'Účet';
	$lang['strchangepassword'] = 'Změna hesla';
	$lang['strpasswordchanged'] = 'Heslo změněno.';
	$lang['strpasswordchangedbad'] = 'Změna hesla se nepodařila.';
	$lang['strpasswordshort'] = 'Heslo je příliš krátké.';
	$lang['strpasswordconfirm'] = 'Heslo a jeho ověření neodpovídá.';
		
	// Groups
	$lang['strgroup'] = 'Skupina';
	$lang['strgroups'] = 'Skupiny';
	$lang['strnogroups'] = 'Nebyly nalezeny žádné skupiny.';
	$lang['strcreategroup'] = 'Vytvořit skupinu';
	$lang['strshowallgroups'] = 'Zobrazit všechny skupiny';
	$lang['strgroupneedsname'] = 'Musíš zadat jméno skupiny.';
	$lang['strgroupcreated'] = 'Skupina vytvořená.';
	$lang['strgroupcreatedbad'] = 'Skupina nebyla vytvořená.';
	$lang['strconfdropgroup'] = 'Opravdu chceš smazat skupinu "%s"?';
	$lang['strgroupdropped'] = 'Skupina smazána.';
	$lang['strgroupdroppedbad'] = 'Skupina nebyla smazána.';
	$lang['straddmember'] = 'Přidej člena';
	$lang['strmemberadded'] = 'Člen přidán.';
	$lang['strmemberaddedbad'] = 'Přidání člena se nepovedlo.';
	$lang['strdropmember'] = 'Odstraň člena';
	$lang['strconfdropmember'] = 'Jseš si opravdu jist, že chceš odstranit člena "%s" ze skupiny "%s"?';
	$lang['strmemberdropped'] = 'Člen odstraněn.';
	$lang['strmemberdroppedbad'] = 'Odstranění člena se nepovedlo.';
	$lang['strmembers'] = 'Členové';

	// Privileges
	$lang['strprivilege'] = 'Oprávnění';
	$lang['strprivileges'] = 'Oprávnění';
	$lang['strnoprivileges'] = 'Tento objekt nemá oprávnění.';
	$lang['strgrant'] = 'Povolit';
	$lang['strrevoke'] = 'Odobrat';
	$lang['strgranted'] = 'Oprávnění přidané.';
	$lang['strgrantbad'] = 'Musíte specifikovat alespoň jednoho uživatele či skupinu a aspoň jedno oprávnění.';
	$lang['stralterprivs'] = 'Uprav oprávnění';
	$lang['strgrantor'] = 'Poskytovatel oprávnění';
	$lang['strasterisk'] = '*';
	$lang['strgrantfailed'] = 'Oprávnění nebylo přidané.';

	
	// Databases
	$lang['strdatabases'] = 'Databáze';
	$lang['strshowalldatabases'] = 'Zobrazit všechny databáze';
	$lang['strnodatabase'] = 'Nenalezena žádná databáze.';
	$lang['strnodatabases'] = 'Nenalezena žádné databáze.';
	$lang['strcreatedatabase'] = 'Vytvořit databázi';
	$lang['strdatabasename'] = 'Název databáze';
	$lang['strdatabaseneedsname'] = 'Musíš zadat název pro databázi.';
	$lang['strdatabasecreated'] = 'Databáze vytvořena.';
	$lang['strsqlexecuted'] = 'SQL provedeno.';
	$lang['strdatabasecreatedbad'] = 'Databáze nebyla vytvořena.';	
	$lang['strconfdropdatabase'] = 'Opravdu chceš smazat databázi "%s"?';
	$lang['strdatabasedropped'] = 'Databáze smazána.';
	$lang['strdatabasedroppedbad'] = 'Databáza nebyla smazána.';
	$lang['strentersql'] = 'Vlož SQL dotaz:';
	$lang['strvacuumgood'] = 'Vyčištění provedeno.';
	$lang['strvacuumbad'] = 'Vyčištění selhalo.';
	$lang['stranalyzegood'] = 'Analýza provedena.';
	$lang['stranalyzebad'] = 'Analýza selhala.';

	// Views
	$lang['strview'] = 'Náhled';
	$lang['strviews'] = 'Náhledy';
	$lang['strshowallviews'] = 'Zobrazit všechny náhledy';
	$lang['strnoview'] = 'Nenalezen žádný náhled.';
	$lang['strnoviews'] = 'Nenalezeny žádné náhledy.';
	$lang['strcreateview'] = 'Vytvořit náhled';
	$lang['strviewname'] = 'Název náhledu';
	$lang['strviewneedsname'] = 'Musíš zadat název náhledu.';
	$lang['strviewneedsdef'] = 'Musíš zadat definici náhledu.';
	$lang['strviewcreated'] = 'Náhled vytvořen.';
	$lang['strviewcreatedbad'] = 'Náhled nebyl vytvořen.';
	$lang['strviewlink'] = 'Spojovací klíče';
	$lang['strviewconditions'] = 'Uprav podmínky';
	$lang['strconfdropview'] = 'Opravdu chceš smazat náhled "%s"?';
	$lang['strviewdropped'] = 'Náhled smazán.';
	$lang['strviewdroppedbad'] = 'Náhled nebyl smazán.';
	$lang['strviewupdated'] = 'Náhled upraven.';
	$lang['strviewupdatedbad'] = 'Náhled nebyl upraven.';

	// Sequences
	$lang['strsequence'] = 'Sekvence';
	$lang['strsequences'] = 'Sekvence';
	$lang['strshowallsequences'] = 'Zobrazit všechny sekvence';
	$lang['strnosequence'] = 'Žádná sekvence nenalezena.';
	$lang['strnosequences'] = 'Žádný sekvence nenalezeny.';
	$lang['strcreatesequence'] = 'Vytvorit sekvenci';
	$lang['strlastvalue'] = 'Poslední hodnota';
	$lang['strincrementby'] = 'Inkrementovat od';	
	$lang['strstartvalue'] = 'Počáteční hodnota';
	$lang['strmaxvalue'] = 'Max hodnota';
	$lang['strminvalue'] = 'Min hodnota';
	$lang['strcachevalue'] = 'Cache hodnota';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = 'Je cyklická?';
	$lang['strsequenceneedsname'] = 'Musíš zadat název sekvence.';
	$lang['strsequencereset'] = 'Reset sekvence.';
	$lang['strsequenceresetbad'] = 'Reset sekvence se nepovedl.';
	$lang['strsequencecreated'] = 'Sekvence vytvořena.';
	$lang['strsequencecreatedbad'] = 'Sekvence nebyla vytvořena.'; 
	$lang['strindex'] = 'Index';
	$lang['strconfdropsequence'] = 'Opravdu chceš smazat sekvence "%s"?';
	$lang['strsequencedropped'] = 'Sekvence smazána.';
	$lang['strsequencedroppedbad'] = 'Sekvence nebyla smazána.';

	// Indexes
	$lang['strindexes'] = 'Indexy';
	$lang['strindexname'] = 'Název indexu';
	$lang['strshowallindexes'] = 'Zobrazit všechny indexy';
	$lang['strnoindex'] = 'Nenalezen žádný index.';
	$lang['strnoindexes'] = 'Nenalezeny žádné index.';
	$lang['strcreateindex'] = 'Vytvořit index';
	$lang['strindexname'] = 'Název indexu';
	$lang['strtabname'] = 'Název tabulky';
	$lang['strcolumnname'] = 'Názov stoupce';
	$lang['strindexneedsname'] = 'Musíš zadat název indexu';
	$lang['strindexneedscols'] = 'Index vyžaduje korektní počet sloupců.';
	$lang['strindexcreated'] = 'Index vytvořen';
	$lang['strindexcreatedbad'] = 'Index nebyl vytvořen.';
	$lang['strconfdropindex'] = 'Opravdu chceš smazat index "%s"?';
	$lang['strindexdropped'] = 'Index smazán.';
	$lang['strindexdroppedbad'] = 'Index nebyl smazán.';
	$lang['strconfcluster'] = 'Chcete opravdu clusterovat "%s"?';
	$lang['strclusteredgood'] = 'Cluster proveden.';
	$lang['strclusteredbad'] = 'Cluster se nepovedl.';
	$lang['strkeyname'] = 'Název klíče';
	$lang['struniquekey'] = 'Unikátní klíč';
	$lang['strprimarykey'] = 'Primární klíč';
 	$lang['strindextype'] = 'Typ indexu';
	$lang['strindexname'] = 'Název indexu';
	$lang['strtablecolumnlist'] = 'Sloupce v tabulce';
	$lang['strindexcolumnlist'] = 'Sloupce v indexu';

	// Rules
	$lang['strrules'] = 'Pravidla';
	$lang['strrule'] = 'Pravidlo';
	$lang['strshowallrules'] = 'Zobrazit všechna pravidla';
	$lang['strnorule'] = 'Nenalezeno žádné pravidlo.';
	$lang['strnorules'] = 'Nenalezeny žádná pravidla.';
	$lang['strcreaterule'] = 'Vytvořit pravidlo';
	$lang['strrulename'] = 'Název pravidla';
	$lang['strruleneedsname'] = 'Musíš zadat název pravidla.';
	$lang['strrulecreated'] = 'Pravidlo vytvořeno.';
	$lang['strrulecreatedbad'] = 'Pravidlo nebylo vytvořeno.';
	$lang['strconfdroprule'] = 'Chceš opravdu smazat pravidlo "%s" na "%s"?';
	$lang['strruledropped'] = 'Pravidlo smazáno.';
	$lang['strruledroppedbad'] = 'Pravidlo nebylo smazáno.';

	// Constraints
	$lang['strconstraints'] = 'Omezení';
	$lang['strshowallconstraints'] = 'Zobrazit všechna omezení';
	$lang['strnoconstraints'] = 'Nenalezeny žádné omezení.';
	$lang['strcreateconstraint'] = 'Vytvořit omezení';
	$lang['strconstraintcreated'] = 'Omezení vytvořeno.';
	$lang['strconstraintcreatedbad'] = 'Omezení nebylo vytvořeno.';
	$lang['strconfdropconstraint'] = 'Chceš opravdu smazat omezení "%s" na "%s"?';
	$lang['strconstraintdropped'] = 'Omezení smazáno.';
	$lang['strconstraintdroppedbad'] = 'Omezení nebylo smazáno.';
	$lang['straddcheck'] = 'Přidat kontrolu';
	$lang['strcheckneedsdefinition'] = 'Je nutné kontrolu omezení definovat.';
	$lang['strcheckadded'] = 'Kontrola omezení přidána.';
	$lang['strcheckaddedbad'] = 'Kontrola omezení nebyla přidána.';
	$lang['straddpk'] = 'Přidat primární klíč';
	$lang['strpkneedscols'] = 'Primární klíč vyžaduje alespoň jeden sloupec.';
	$lang['strpkadded'] = 'Primární klíč přidán.';
	$lang['strfkneedstarget'] = 'Cizí klíč vyžaduje cílovou tabulku.';
	$lang['strpkaddedbad'] = 'Primární klíč nebyl přidán.';
	$lang['stradduniq'] = 'Přidat unikátní klíč';
	$lang['struniqneedscols'] = 'Unikátní klíč vyžaduje alespoň jeden sloupec.';
	$lang['strfkcolumnlist'] = 'Sloupce v klíči';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';
	$lang['struniqadded'] = 'Unikátní klíč přidán.';
	$lang['struniqaddedbad'] = 'Unikátní klíč nebyl přidán.';
	$lang['straddfk'] = 'Přidat cizí klíč';
	$lang['strfkneedscols'] = 'Cizí klíč vyžaduje alespoň jeden sloupec.';
	$lang['strfkadded'] = 'Cizí klíč přidán.';
	$lang['strfkaddedbad'] = 'Cizí klíč nebyl přidán.';
	$lang['strfktarget'] = 'Cílová tabulka';

	// Functions
	$lang['strfunction'] = 'Funkce';
	$lang['strfunctions'] = 'Funkce';
	$lang['strshowallfunctions'] = 'Zobrazit všechny funkce';
	$lang['strnofunction'] = 'Nenalezena žádná funkce.';
	$lang['strnofunctions'] = 'Nenalezeny žádné funkce.';
	$lang['strcreatefunction'] = 'Vytvořit funkci';
	$lang['strfunctionname'] = 'Název funkce';
	$lang['strreturns'] = 'Vrací';
	$lang['strarguments'] = 'Argumenty';
	$lang['strproglanguage'] = 'Jazyk';
	$lang['strfunctionneedsname'] = 'Musíš zadat název funkce.';
	$lang['strfunctionneedsdef'] = 'Musíš zadat definici funkce.';
	$lang['strfunctioncreated'] = 'Funkce vytvořena.';
	$lang['strfunctioncreatedbad'] = 'Funkce nebyla vytvořena.';
	$lang['strconfdropfunction'] = 'Opravdu chceš smazat funkci "%s"?';
	$lang['strfunctiondropped'] = 'Funkce smazána.';
	$lang['strfunctiondroppedbad'] = 'Funkce nebyla smazána.';
	$lang['strfunctionupdated'] = 'Funkce upravena.';
	$lang['strfunctionupdatedbad'] = 'Funkce nebyla upravena.';

	// Triggers
	$lang['strtrigger'] = 'Trigger';
	$lang['strtriggers'] = 'Triggers';
	$lang['strshowalltriggers'] = 'Zobrazit všechny triggery';
	$lang['strnotrigger'] = 'Nenalezen žádný trigger.';
	$lang['strnotriggers'] = 'Nenalezeny žádné triggery.';
	$lang['strcreatetrigger'] = 'Vytvořit trigger';
	$lang['strtriggeraltered'] = 'Trigger změněn.';
	$lang['strtriggeralteredbad'] = 'Změna triggeru se nepovedla.';
	$lang['strtriggerneedsname'] = 'Musíš zadat název triggeru.';
	$lang['strtriggerneedsfunc'] = 'Musíš zadat funkci triggeru.';
	$lang['strtriggercreated'] = 'Trigger vytvořen.';
	$lang['strtriggercreatedbad'] = 'Trigger nebyl vytvořen.';
	$lang['strconfdroptrigger'] = 'Chceš opravdu smazat trigger "%s" na "%s"?';
	$lang['strtriggerdropped'] = 'Trigger smazán.';
	$lang['strtriggerdroppedbad'] = 'Trigger nebyl smazán.';

	// Types
	$lang['strtype'] = 'Typ';
	$lang['strtypes'] = 'Typy';
	$lang['strshowalltypes'] = 'Zobrazit všechny typy';
	$lang['strnotype'] = 'Nenalezený žádný typ.';
	$lang['strnotypes'] = 'Nenalezeny žádné typy.';
	$lang['strcreatetype'] = 'Vytvořit typ';
	$lang['strtypename'] = 'Název typu';
	$lang['strinputfn'] = 'Vstupní funkce';
	$lang['stroutputfn'] = 'Výstupní funkce';
	$lang['strpassbyval'] = 'Volán hodnotou?';
	$lang['stralignment'] = 'Zarovnání';
	$lang['strelement'] = 'Element';
	$lang['strdelimiter'] = 'Oddělovač';
	$lang['strstorage'] = 'Storage';
	$lang['strtypeneedsname'] = 'Musíš zadat název typu.';
	$lang['strtypeneedslen'] = 'Musíš zadat délku typu.';
	$lang['strtypecreated'] = 'Typ vytvořen.';
	$lang['strtypecreatedbad'] = 'Typ nebyl vytvořen.';
	$lang['strconfdroptype'] = 'Chceš opravdu smazat typ "%s"?';
	$lang['strtypedropped'] = 'Typ smazán.';
	$lang['strtypedroppedbad'] = 'Typ nebyl smazán.';

	// Schemas
	$lang['strschema'] = 'Schéma';
	$lang['strschemas'] = 'Schémata';
	$lang['strshowallschemas'] = 'Zobrazit všechny schémata';
	$lang['strnoschema'] = 'Nenalezeno žádné schéma.';
	$lang['strnoschemas'] = 'Nenalezeny žádné schémata.';
	$lang['strcreateschema'] = 'Vytvorit schéma';
	$lang['strschemaname'] = 'Název schématu';
	$lang['strschemaneedsname'] = 'Musíš zadat název schématu.';
	$lang['strschemacreated'] = 'Schéma vytvořeno.';
	$lang['strschemacreatedbad'] = 'Schéma nebylo vytvořeno.';
	$lang['strconfdropschema'] = 'Chceš opravdu smazat schéma "%s"?';
	$lang['strschemadropped'] = 'Schéma smazáno.';
	$lang['strschemadroppedbad'] = 'Schéma nebylo smazáno.';

	// Reports
	$lang['strreport'] = 'Report';
	$lang['strreports'] = 'Reporty';
	$lang['strshowallreports'] = 'Zobrazit všechny reporty';
	$lang['strnoreports'] = 'Nenalezeny žádné reporty.';
	$lang['strcreatereport'] = 'Vytvořit report';
	$lang['strreportdropped'] = 'Report smazán.';
	$lang['strreportdroppedbad'] = 'Report nebyl smazán.';
	$lang['strdomain'] = 'Doména';
	$lang['strdomains'] = 'Domény';
	$lang['strshowalldomains'] = 'Ukaž všechny domény';
	$lang['strnodomains'] = 'Žádné domény nenalezeny.';
	$lang['strcreatedomain'] = 'Vytvoř doménu';
	$lang['strdomaindropped'] = 'Doména odstraněna.';
	$lang['strdomaindroppedbad'] = 'Odstranění domény se nepovedlo.';
	$lang['strconfdropdomain'] = 'Chceš opravdu odstranit doménu "%s"?';
	$lang['strdomainneedsname'] = 'Musíte zadat jméno domény.';
	$lang['strdomaincreated'] = 'Doména vytvořena.';
	$lang['strdomaincreatedbad'] = 'Vytvoření domény se nepovedlo.';
	$lang['strdomainaltered'] = 'Domain změněna.';
	$lang['strdomainalteredbad'] = 'Změna domény se nepovelda.';
	$lang['strconfdropreport'] = 'Opravdu chceš smazat report "%s"?';
	$lang['strreportneedsname'] = 'Musíš zadat název reportu.';
	$lang['stroperator'] = 'Operátor';
	$lang['strreportneedsdef'] = 'Musíš zadat SQL dotaz pro report.';
	$lang['strshowalloperators'] = 'Ukaž všechny operátory';
	$lang['strnooperator'] = 'Žádný operátor nenalezen.';
	$lang['strnooperators'] = 'Žádné operátory nenalezeny.';
	$lang['strcreateoperator'] = 'Vytvoř operátor';
	$lang['strleftarg'] = 'Typ levého argumentu';
	$lang['strrightarg'] = 'Typ pravého argumenti';
	$lang['strcommutator'] = 'Komutátor';
	$lang['strnegator'] = 'Negátor';
	$lang['strrestrict'] = 'Omezení';
	$lang['strjoin'] = 'Join';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Levé třídění';
	$lang['strrightsort'] = 'Pravé třídění';
	$lang['strlessthan'] = 'Méně než';
	$lang['strgreaterthan'] = 'Více než';
	$lang['stroperatorneedsname'] = 'Musíte zadat jméno operátoru.';
	$lang['stroperatorcreated'] = 'Operátor vytvořen';
	$lang['stroperatorcreatedbad'] = 'Vytvoření operátoru se nepovedlo.';
	$lang['strconfdropoperator'] = 'Opravdu chceš smazat operátor "%s"?';
	$lang['stroperatordropped'] = 'Operátor smazán.';
	$lang['stroperatordroppedbad'] = 'Smazání operátoru se nepovedlo.';
	$lang['strreportcreated'] = 'Report uložen.';
	$lang['strreportcreatedbad'] = 'Report nebyl uložen.';
	$lang['strcasts'] = 'Casts';
	$lang['strnocasts'] = 'No casts found.';
	$lang['strsourcetype'] = 'Zdrojový typ';
	$lang['strtargettype'] = 'Cílový typ';
	$lang['strimplicit'] = 'Implictně';
	$lang['strinassignment'] = 'V přiřazení';
	$lang['strbinarycompat'] = '(binárně kompatibilní)';

	// Miscellaneous
	$lang['strconversions'] = 'Konverze';
	$lang['strnoconversions'] = 'Žádné konverze nenalezeny.';
	$lang['strsourceencoding'] = 'Zdrojové kódování';
	$lang['strtargetencoding'] = 'Cilové kódování';
	$lang['strtopbar'] = '%s beží na %s:%s -- Jsi přihlášený jako "%s", %s';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strlanguages'] = 'Jazyky';
	$lang['strnolanguages'] = 'Žádné jazyky nenalezeny.';
	$lang['strtrusted'] = 'Důvěryhodný';

	$lang['strdataonly'] = 'Pouze data';
	$lang['strusers'] = 'Uživatelé';
	$lang['strnogroup'] = 'Skupina nenalezena.';
	$lang['strdatabase'] = 'Databáze';
	$lang['strnoinfo'] = 'Nejsou dostupné žádné informace.';
	$lang['strreferringtables'] = 'Odkazované tabulky';
	$lang['strparenttables'] = 'Tabulky rodičů';
	$lang['strchildtables'] = 'Tabulky potomků';
	$lang['strnoaggregates'] = 'Nebyla nalezena žádná agregace.';
	$lang['stralltypes'] = '(Všechny typy)';
	$lang['stropclasses'] = 'Třídy operátorů';
	$lang['strnoopclasses'] = 'Nebyly nalezeny žádné třídy operátorů.';
	$lang['straccessmethod'] = 'Přístupová metoda';	
	$lang['strrowperf'] = 'Výkon řádku';
	$lang['strioperf'] = 'I/O výkon';
	$lang['stridxrowperf'] = 'Výkon indexu řádku';
	$lang['stridxioperf'] = 'I/O výkon indexu';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Sekvenčníé';
	$lang['strscan'] = 'Scan';
	$lang['strread'] = 'Read';
	$lang['strfetch'] = 'Fetch';
	$lang['strheap'] = 'Heap';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST Index';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disk';
	$lang['strrows2'] = 'Řádků';
	$lang['strhelp'] = 'Nápověda';

?>
